# Bibliography

[//]: # (This file is manually generated and updated)
[//]: # (When adding a new bibliographic reference, )
[//]: # (import it using Zotero, then)
[//]: # (select it, right click and select:)
[//]: # (Create Bibliography from item...)
[//]: # (and then selecting the style:)
[//]: # (Chicago Manual of Style 17th edition (author-date))
[//]: # (Copy paste de generated bibliography here)
[//]: # (make sure to format any url appropriately)
[//]: # (finally add an html anchor matching the bibliographic key)


* <a name="Anderson+1986"></a> Anderson, G. P., S. A. Clough, F. X. Kneizys, J. H. Chetwynd, and E. P. Shettle. 1986. ‘AFGL Atmospheric Constituent Profiles (0.120km)’. AFGL-TR-0208 Environemental Research Papers, May. [http://adsabs.harvard.edu/abs/1986afgl.rept.....A](http://adsabs.harvard.edu/abs/1986afgl.rept.....A).

* <a name="NOAA+1976"></a> United States National Oceanic and Atmospheric Administration and United States Committee on Extension to the Standard Atmosphere. 1976. ‘U.S. Standard Atmosphere, 1976’. NOAA-S/T-76-1562. [https://ntrs.nasa.gov/citations/19770009539](https://ntrs.nasa.gov/citations/19770009539).

* <a name="Remedios+2007"></a> Remedios, J. J., R. J. Leigh, A. M. Waterfall, D. P. Moore, H. Sembhi, I. Parkes, J. Greenhough, M. P. Chipperfield, and D. Hauglustaine. 2007. ‘MIPAS Reference Atmospheres and Comparisons to V4.61/V4.62 MIPAS Level 2 Geophysical Data Sets’. Atmospheric Chemistry and Physics Discussions 7 (4): 9973–10017. [https://doi.org/10.5194/acpd-7-9973-2007](https://doi.org/10.5194/acpd-7-9973-2007).
